# Onionbalance

![Onionbalance](assets/onionbalance.jpg)

## Overview

Onionbalance is the best way to load balance onion services across
multiple backend Tor instances. This way the load of introduction and
rendezvous requests get distributed across multiple hosts. Onionbalance
provides load-balancing while also making onion services more resilient
and reliable by eliminating single points-of-failure.

* Repository:
  [https://gitlab.torproject.org/tpo/onion-services/onionbalance][]
* GitHub mirror:
  [https://github.com/torproject/onionbalance][]
* Issue tracker:
  [https://gitlab.torproject.org/tpo/onion-services/onionbalance/-/issues][]
* PyPI: [https://pypi.org/project/Onionbalance][]
* IRC: #tor-dev @ OFTC

[https://gitlab.torproject.org/tpo/onion-services/onionbalance]: https://gitlab.torproject.org/tpo/onion-services/onionbalance
[https://github.com/torproject/onionbalance]: https://github.com/torproject/onionbalance
[https://gitlab.torproject.org/tpo/onion-services/onionbalance/-/issues]: https://gitlab.torproject.org/tpo/onion-services/onionbalance/-/issues
[https://pypi.org/project/Onionbalance]: https://pypi.org/project/Onionbalance

## Quickstart

Check the [v3 tutorial](v3/tutorial.md) page for setting up a v3 onionbalance.
